#
# spec file for package gap-digraphs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gap-digraphs
Version:        0.11.0
Release:        lp150.1.2
Summary:        GAP: Digraphs and multigraphs
License:        GPL-3.0+
Group:          Productivity/Scientific/Math
Url:            http://www-groups.mcs.st-andrews.ac.uk/~jamesm/digraphs.php

Source:         https://www.gap-system.org/pub/gap/gap4/tar.bz2/packages/digraphs-%version.tar.bz2
Patch1:         digraphs-no-native.diff
Patch2:         0001-Drop-bad-include-of-x86intrin.h.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gap-devel
BuildRequires:  gap-rpm-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       gap-core >= 4.8.2
Requires:       gap-io >= 4.4.6
Requires:       gap-orb >= 4.7.5
Suggests:       gap-gapdoc >= 1.5.1
Suggests:       gap-grape >= 4.5
Suggests:       gap-nautytracesinterface >= 0.2
# Source contains a modified copy of bliss-0.73, so we cannot reuse bliss-devel
Provides:       bundled(bliss) = 0.73

%description
The Digraphs package is a GAP package containing methods for digraphs
and multidigraphs.

%prep
%setup -qn digraphs-%version
%patch -P 1 -P 2 -p1

%build
autoreconf -fi
%configure --with-gaproot="%gapdir"
make %{?_smp_mflags}
find . -type f -name "*~" -delete

%install
find . -type f -name .dirstamp -print -delete
# delete tests and assets
rm -Rf tst data/symmetric-closure.ds6.gz data/test-1.d6
# delete sources and build artifacts, user is not expected to rebuild in distribution tree
rm -Rf autom4te.cache src cnf config* m4 autogen.sh aclocal.m4 *.la Makefile*

%gappkg_simple_install
%fdupes %buildroot/%_prefix
find %buildroot

%files -f %name.files
%defattr(-,root,root)

%changelog
* Fri Jan 26 2018 stefan.bruens@rwth-aachen.de
- Remove all transient build artifacts (e.g. config.log) to make
  build reproducible
- delete remaining sources and test assets
* Fri Jan 26 2018 stefan.bruens@rwth-aachen.de
- Add 0001-Drop-bad-include-of-x86intrin.h.patch
  Remove unnecessary include of x86intrin.h, breaks compilation on
  anything but x86.
* Fri Jan 26 2018 guillaume@opensuse.org
- Add ExclusiveArch for x86 and x86_64 since it needs 'x86intrin.h'
* Sat Dec 23 2017 jengelh@inai.de
- Update to new upstream release 0.11.0
  * Support for computing automorphisms, canonical labellings,
    and isomorphisms of digraphs with "nauty". This functionality
    requires the gap-nautytracesinterface package for GAP.
    However, this is not a required package, and the default
    engine remains "bliss". It is possible to specify the engine
    that is used by Digraphs.
  * In particular, version 0.11.0 includes the following changes:
  * `BlissAutomorphismGroup` and `NautyAutomorphismGroup` are
    introduced.
  * `DigraphCanonicalLabelling` is replaced by
    `BlissCanonicalLabelling` and `NautyCanonicalLabelling`.
  * `BlissCanonicalDigraph` and `NautyCanonicalDigraph` are
    introduced
  * `DigraphsUseNauty` and `DigraphsUseBliss` are introduced.
  * The property `IsHamiltonianDigraph` and the attribute
    `HamiltonianPath` were added.
- Add digraphs-no-native.diff
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 0.10.1
  * This release contains new features, bugfixes, and minor
    improvements to the documentation. There is a new method for
    `ChromaticNumber`, which has better performance than the
    previous method.
  * A bug in the code for calculating homomorphisms of digraphs,
    which could cause a crash, was resolved.
  * Vertex labelled digraphs can now be visualised in a way that
    displays vertex labels, by using the new operation
    `DotVertexLabelledDigraph`.
  * The attribute `CliqueNumber` is introduced.
  * The following new attributes for Cayley digraphs are
    introduced: `GroupOfCayleyDigraph`,
    `SemigroupOfCayleyDigraph`, `GeneratorsOfCayleyDigraph`.
  * New features introduced in 0.9.0: `ArticulationPoints` (and
    its synonym `CutVertices`), `IsBiconnectedDigraph`
    `IsCycleDigraph`, `IsMatching`, `IsPerfectMatching`,
    `IsMaximalMatching`.
  * New features introduced in 0.8.0: `DigraphClosure`,
    `BooleanAdjacencyMatrixMutableCopy`, `IsPartialOrderDigraph`,
    `IsMeetSemilatticeDigraph`, `IsJoinSemilatticeDigraph`,
    `IsLatticeDigraph`, `PartialOrderDigraphMeetOfVertices`,
    `PartialOrderDigraphJoinOfVertices`.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 0.7.1
  * This release contains a new technique for encoding a
    vertex-coloured `multidigraph` as a vertex-coloured
    (undirected) graph while preserving the automorphism group,
    in order to calculate the automorphism group and canonical
    labelling using bliss. This enables the following
    functionality:
  * * the operations `AutomorphismGroup` and
    `DigraphCanonicalLabelling` for a digraph and a
    vertex-colouring now accept a multidigraph as their first
    argument;
  * * the operations `IsIsomorphicDigraph` and
    `IsomorphismDigraphs` now accept multidigraphs, and they
    also accept vertex-colourings as optional arguments.
  * This release add new functionality related to undirected
    spanning trees and undirected spanning forests:
  * * The property `IsUndirectedForest` is introduced;
  * * The attributes `UndirectedSpanningTree` and
    `UndirectedSpanningForest` are introduced; and
  * * The operations `IsUndirectedSpanningTree` and
    `IsUndirectedSpanningForest` are introduced.
* Sun Oct 16 2016 jengelh@inai.de
- Update to new upstream release 0.5.2
  * Digraphs now works when it and GAP are built in 32-bit mode.
- Update to new upstream release 0.5.1
  * This release contains a new technique for encoding a
  vertex-coloured digraph as a vertex-coloured (undirected) graph
  while preserving the automorphism group, in order to calculate
  the automorphism group using bliss.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 0.5
  * Unspecified bugfixes
* Fri Mar 11 2016 jengelh@inai.de
- Initial packages (version 0.4.2) for build.opensuse.org
